==> 0.3.1%2B1.tar.gz: example/lib/screens/scanner.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:shared_preferences/shared_preferences.dart';

import 'package:snowm_scanner/snowm_scanner.dart';
import 'package:snowm_scanner_example/widgets/bluetooth_status.dart';

class ScannerScreen extends StatefulWidget {
  @override
  _ScannerScreenState createState() => _ScannerScreenState();
}

class _ScannerScreenState extends State<ScannerScreen> {
  bool isScanning = false;

  List<SnowMBeacon> scannedBeacons = [];

  var sKey = GlobalKey<ScaffoldState>();
  ScaffoldFeatureController<SnackBar, SnackBarClosedReason> snackbar;
  List<String> uuids = ["42524149-4e41-4e54-5330-303030303034"];

  var _uuidController = TextEditingController();
  StreamSubscription controller;

  scanBeacons() {
    setState(() {
      isScanning = true;
    });
    controller = snowmScanner.scanBeacons(uuids: uuids).listen((beacons) {
      setState(() {
        this.scannedBeacons = beacons;
      });
    });
  }

  void backgroundScanning() async {
    await snowmScanner.scanBeaconsInBackground(uuids);
  }

  manageButton() {
    if (controller == null)
      scanBeacons();
    else
      stopScan();
  }

  stopScan() {
    controller.cancel();
    controller = null;
    setState(() {
      isScanning = false;
    });
  }

  showSnackbar(String message) {
    snackbar = sKey.currentState.showSnackBar(
      SnackBar(
        content: Text(message),
        behavior: SnackBarBehavior.floating,
        duration: Duration(seconds: 5),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    snowmScanner.configure(enableMqtt: true);
    initAsync();
  }

  SharedPreferences prefs;

  initAsync() async {
    prefs = await SharedPreferences.getInstance();
    setState(() {
      uuids = prefs.getStringList("uuids") ?? [];
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: sKey,
      body: Column(
        children: <Widget>[
          Expanded(
            child: Container(
              padding: EdgeInsets.all(20),
              color: Theme.of(context).primaryColor,
              width: MediaQuery.of(context).size.width,
              alignment: Alignment.center,
              child: SafeArea(
                child: Container(
                  child: Text(
                    "SnowM Beacon\n Scanner",
                    textAlign: TextAlign.center,
                    style: Theme.of(context).accentTextTheme.headline3,
                  ),
                ),
              ),
            ),
          ),
          BluetoothStatus(),
          Expanded(
            flex: 3,
            child: SingleChildScrollView(
              child: Column(
                children: <Widget>[
                  ListTile(
                    title: Text(
                      "Beacons to Scan",
                      style: TextStyle(
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ),
                  for (String uuid in uuids)
                    ListTile(
                      title: Text(uuid),
                      trailing: IconButton(
                        icon: Icon(Icons.delete),
                        onPressed: () {
                          setState(() {
                            uuids.removeWhere((element) => element == uuid);
                            prefs.setStringList("uuids", uuids);
                          });
                        },
                      ),
                    ),
                  Padding(
                    padding: const EdgeInsets.fromLTRB(20, 0, 20, 0),
                    child: TextField(
                      controller: _uuidController,
                      decoration: InputDecoration(
                        hintText: 'eg:42524149-4e41-4e54-5330-303030303036',
                        labelText: 'Add UUID to scan',
                        suffixIcon: IconButton(
                            icon: Icon(Icons.add),
                            onPressed: () {
                              if (_uuidController != null &&
                                  _uuidController.text.isNotEmpty) {
                                setState(() {
                                  uuids.add(_uuidController.text);
                                  _uuidController.clear();
                                  prefs.setStringList("uuids", uuids);
                                });
                              }
                            }),
                      ),
                      maxLength: 36,
                    ),
                  ),
                  FlatButton(
                    child: Text(
                      controller == null ? "Scan Beacons" : "Stop Scanning",
                    ),
                    onPressed: manageButton,
                  ),
                  FlatButton(
                    child: Text("Background Scanning"),
                    onPressed: backgroundScanning,
                  ),
                  FlatButton(
                    child: Text("Stop background scanning"),
                    onPressed: stopBackgroundScanning,
                  ),
                  for (SnowMBeacon beacon in scannedBeacons)
                    BeaconTile(beacon: beacon)
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }

  void stopBackgroundScanning() async {
    await snowmScanner.stopBackgroudScan();
  }
}

class BeaconTile extends StatelessWidget {
  const BeaconTile({
    Key key,
    @required this.beacon,
  }) : super(key: key);

  final SnowMBeacon beacon;

  @override
  Widget build(BuildContext context) {
    return ListTile(
      leading: Icon(Icons.bluetooth_searching),
      title: Text("UUID:" + beacon.uuid),
      subtitle: Text("MAC address:" +
          beacon.macAddress +
          "\n" +
          "Distance:" +
          beacon.distance.toStringAsFixed(2) +
          "\n" +
          "Major/Minor:" +
          beacon.major.toString() +
          "/" +
          beacon.minor.toString() +
          "\ntxPower:" +
          beacon.txPower.toString() +
          "\n" +
          "rssi:" +
          beacon.rssi.toString()),
      trailing: IconButton(
          icon: Icon(Icons.content_copy),
          onPressed: () {
            Clipboard.setData(ClipboardData(text: beacon.uuid));
          }),
      isThreeLine: true,
    );
  }
}

==> 0.4.0%2B1.tar.gz: example/lib/screens/scanner.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:shared_preferences/shared_preferences.dart';

import 'package:snowm_scanner/snowm_scanner.dart';
import 'package:snowm_scanner_example/widgets/bluetooth_status.dart';

class ScannerScreen extends StatefulWidget {
  @override
  _ScannerScreenState createState() => _ScannerScreenState();
}

class _ScannerScreenState extends State<ScannerScreen> {
  bool isScanning = false;

  List<SnowMBeacon> scannedBeacons = [];

  var sKey = GlobalKey<ScaffoldState>();
  ScaffoldFeatureController<SnackBar, SnackBarClosedReason> snackbar;
  List<String> uuids = ["42524149-4e41-4e54-5330-303030303034"];

  var _uuidController = TextEditingController();
  StreamSubscription controller;

  scanBeacons() {
    setState(() {
      isScanning = true;
    });
    controller = snowmScanner.scanBeacons(uuids: uuids).listen((beacons) {
      setState(() {
        this.scannedBeacons = beacons;
      });
    });
  }

  void backgroundScanning() async {
    await snowmScanner.scanBeaconsInBackground(
      uuids,
      geofence: Geofence(
        identifier: "background",
        latitude: 27.743337,
        longitude: 85.320332,
        radius: 1000,
      ),
    );
    // await snowmScanner.startGeofencing(
    //   Geofence(
    //     identifier: "this is a",
    //     latitude: 28.88,
    //     longitude: 87.33,
    //     radius: 1000,
    //   ),
    // );
  }

  manageButton() {
    if (controller == null)
      scanBeacons();
    else
      stopScan();
  }

  stopScan() {
    controller.cancel();
    controller = null;
    setState(() {
      isScanning = false;
    });
  }

  showSnackbar(String message) {
    snackbar = sKey.currentState.showSnackBar(
      SnackBar(
        content: Text(message),
        behavior: SnackBarBehavior.floating,
        duration: Duration(seconds: 5),
      ),
    );
  }

  @override
  void initState() {
    super.initState();
    snowmScanner.configure(enableMqtt: true);
    initAsync();
  }

  SharedPreferences prefs;

  initAsync() async {
    prefs = await SharedPreferences.getInstance();
    setState(() {
      uuids = prefs.getStringList("uuids") ?? [];
    });
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: sKey,
      body: Column(
        children: <Widget>[
          Expanded(
            child: Container(
              padding: EdgeInsets.all(20),
              color: Theme.of(context).primaryColor,
              width: MediaQuery.of(context).size.width,
              alignment: Alignment.center,
              child: SafeArea(
                child: Container(
                  child: Text(
                    "SnowM Beacon\n Scanner",
                    textAlign: TextAlign.center,
                    style: Theme.of(context).accentTextTheme.headline3,
                  ),
                ),
              ),
            ),
          ),
          BluetoothStatus(),
          Expanded(
            flex: 3,
            child: SingleChildScrollView(
              child: Column(
                children: <Widget>[
                  ListTile(
                    title: Text(
                      "Beacons to Scan",
                      style: TextStyle(
                        fontWeight: FontWeight.bold,
                      ),
                    ),
                  ),
                  for (String uuid in uuids)
                    ListTile(
                      title: Text(uuid),
                      trailing: IconButton(
                        icon: Icon(Icons.delete),
                        onPressed: () {
                          setState(() {
                            uuids.removeWhere((element) => element == uuid);
                            prefs.setStringList("uuids", uuids);
                          });
                        },
                      ),
                    ),
                  Padding(
                    padding: const EdgeInsets.fromLTRB(20, 0, 20, 0),
                    child: TextField(
                      controller: _uuidController,
                      decoration: InputDecoration(
                        hintText: 'eg:42524149-4e41-4e54-5330-303030303036',
                        labelText: 'Add UUID to scan',
                        suffixIcon: IconButton(
                            icon: Icon(Icons.add),
                            onPressed: () {
                              if (_uuidController != null &&
                                  _uuidController.text.isNotEmpty) {
                                setState(() {
                                  uuids.add(_uuidController.text);
                                  _uuidController.clear();
                                  prefs.setStringList("uuids", uuids);
                                });
                              }
                            }),
                      ),
                      maxLength: 36,
                    ),
                  ),
                  FlatButton(
                    child: Text(
                      controller == null ? "Scan Beacons" : "Stop Scanning",
                    ),
                    onPressed: manageButton,
                  ),
                  FlatButton(
                    child: Text("Background Scanning"),
                    onPressed: backgroundScanning,
                  ),
                  FlatButton(
                    child: Text("Stop background scanning"),
                    onPressed: stopBackgroundScanning,
                  ),
                  for (SnowMBeacon beacon in scannedBeacons)
                    BeaconTile(beacon: beacon)
                ],
              ),
            ),
          ),
        ],
      ),
    );
  }

  void stopBackgroundScanning() async {
    await snowmScanner.stopBackgroudScan();
  }
}

class BeaconTile extends StatelessWidget {
  const BeaconTile({
    Key key,
    @required this.beacon,
  }) : super(key: key);

  final SnowMBeacon beacon;

  @override
  Widget build(BuildContext context) {
    return ListTile(
      leading: Icon(Icons.bluetooth_searching),
      title: Text("UUID:" + beacon.uuid),
      subtitle: Text("MAC address:" +
          beacon.macAddress +
          "\n" +
          "Distance:" +
          beacon.distance.toStringAsFixed(2) +
          "\n" +
          "Major/Minor:" +
          beacon.major.toString() +
          "/" +
          beacon.minor.toString() +
          "\ntxPower:" +
          beacon.txPower.toString() +
          "\n" +
          "rssi:" +
          beacon.rssi.toString()),
      trailing: IconButton(
          icon: Icon(Icons.content_copy),
          onPressed: () {
            Clipboard.setData(ClipboardData(text: beacon.uuid));
          }),
      isThreeLine: true,
    );
  }
}
